==============
 glance_store
==============

The glance_store library supports the creation, deletion and gather of data
assets from/to a set of several, different, storage technologies.

.. warning::
   This library has been extracted from the Glance source code for the
   specific use of the Glance and Glare projects.

   The API it exposes is not stable, has some shortcomings, and is not a
   general purpose interface. We would eventually like to change this, but for
   now using this library outside of Glance or Glare will not be supported by
   the core team.

.. toctree::
   :maxdepth: 1

   user/index
   reference/index

.. rubric:: Indices and tables

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
